@@ -97,9 +97,8 @@ def extjs_l10n_view(request):
     To work properly, it should be included as late as possible.
     """
 
-    from pyramid.i18n import get_locale_name
     request.response.content_type = 'text/javascript'
-    name = get_locale_name(request)
+    name = request.locale_name
     return {'lang': name}
 
 
@@ -114,10 +113,9 @@ def catalog_view(request):
     """
 
     from simplejson import dumps
-    from pyramid.i18n import get_localizer, get_locale_name
 
-    locale = get_localizer(request)
-    name = get_locale_name(request)
+    locale = request.localizer
+    name = request.locale_name
 
     domain = request.registry.settings.get('desktop.domain', None)
     if domain is None:
@@ -129,9 +127,12 @@ def catalog_view(request):
         app_catalog = locale.translations._domains[domain]
         desktop_catalog = locale.translations._domains['mp-desktop']
     except KeyError:
-        logger.warning('Could not find "%s" translation catalog for "%s",'
-                       ' maybe it has not been compiled? Falling back to'
-                       ' "en".', domain, name)
+        # Usually the "en" language is native, no external catalog
+        # exists for it
+        if name != 'en':
+            logger.warning('Could not find "%s" translation catalog for "%s",'
+                           ' maybe it has not been compiled? Falling back to'
+                           ' "en".', domain, name)
         name = 'en'
         plural_forms = '(n != 1)'
         msgs = {}
